@@ -6,11 +6,9 @@ use Pcore::Lib::Scalar qw[weaken];
 use Pcore::WebSocket::raw;
 
 use overload    #
-  q[&{}] => sub ( $self, @ ) {
+  '&{}' => sub ( $self, @ ) {
     return sub {
-        my $cb = is_plain_coderef $_[-1] ? pop @_ : undef;
-
-        return $self->_call( shift, {@_}, $cb );
+        return $self->_call(@_);
     };
   },
   fallback => undef;
